==> hubzero-submit-monitors_3.2.9-1+deb7.tar.gz: source/monitorJobP.py <==
#!/usr/bin/env python
#
# @package      hubzero-submit-monitors
# @file         monitorJobP.py
# @author       Steven Clark <clarks@purdue.edu>
# @copyright    Copyright (c) 2004-2015 HUBzero Foundation, LLC.
# @license      http://opensource.org/licenses/MIT MIT
#
# Copyright (c) 2004-2015 HUBzero Foundation, LLC.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
# HUBzero is a registered trademark of HUBzero Foundation, LLC.
#
# ----------------------------------------------------------------------
#  monitorJobP.py
#
#  script which queries monitorJob.py for user priorities
#
import sys
import os
import time
import logging

from hubzero.submit.DaemonsInfo      import DaemonsInfo
from hubzero.submit.RemoteJobMonitor import RemoteJobMonitor

CONFIGURATIONDIRECTORY   = os.path.join(os.sep,'etc','submit')
DAEMONSCONFIGURATIONFILE = 'daemons.conf'

APPLICATIONLOGGER = logging.getLogger('') 

def openLogger():
   class EmptyFilter(logging.Filter):
      """
      This is a filter which rejects empty messages

      """

      def filter(self,record):
         if record.getMessage() == "":
            emptyRecord = True
         else:
            emptyRecord = False

         return(not emptyRecord)

   APPLICATIONLOGGER.setLevel(logging.DEBUG)

   logHandler = logging.StreamHandler()

   emptyFilter = EmptyFilter()
   logHandler.addFilter(emptyFilter)

   logFormatter = logging.Formatter('%(asctime)s %(message)s','[%a %b %d %H:%M:%S %Y]')
   logHandler.setFormatter(logFormatter)
   APPLICATIONLOGGER.addHandler(logHandler)


def monitorJobP(listenURI):
   """Report user priorities"""
   if len(sys.argv) == 1:
      hubUserIds = [os.getuid()]
   else:
      hubUserIds = []
      for arg in sys.argv[1:]:
         hubUserIds.append(int(arg))

   remoteJobMonitor = RemoteJobMonitor(listenURI)

   report = remoteJobMonitor.queryUsersPriority(hubUserIds)

   if len(report['usersPriority']) > 0:
      print "Report time %s" % (time.ctime(report['reportTime']))

      print "%32s %8s  %12s\n" % ('Aggregator','UserId','Priority')
      aggregators = report['usersPriority'].keys()
      aggregators.sort()
      for aggregator in aggregators:
         sortedPriorities = sorted([(priority,hubUserId) for hubUserId,priority in report['usersPriority'][aggregator].iteritems()],
                                                                                                                       reverse=True)
         for priority,hubUserId in sortedPriorities:
            print "%32s %8d  %12.3f" % (aggregator,hubUserId,priority)
   else:
      print "Current time %s" % (time.ctime())
      print "No priorities currently being reported"


if __name__ == '__main__':
   openLogger()

   configFilePath = os.path.join(CONFIGURATIONDIRECTORY,DAEMONSCONFIGURATIONFILE)
   daemonsInfo    = DaemonsInfo(configFilePath)
   listenURI      = daemonsInfo.getDaemonListenURI('jobMonitor','tcp')

   monitorJobP(listenURI)

==> hubzero-submit-monitors_3.8.1-1+deb7.tar.gz: source/monitorJobP.py <==
#!/usr/bin/env python3
#
# @package      hubzero-submit-monitors
# @file         monitorJobP.py
# @copyright    Copyright (c) 2004-2020 The Regents of the University of California.
# @license      http://opensource.org/licenses/MIT MIT
#
# Copyright (c) 2004-2020 The Regents of the University of California.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
# HUBzero is a registered trademark of The Regents of the University of California.
#
# ----------------------------------------------------------------------
#  monitorJobP.py
#
#  script which queries monitorJob.py for user priorities
#
import sys
import os
import time
import logging

from hubzero.submit.DaemonsInfo      import DaemonsInfo
from hubzero.submit.RemoteJobMonitor import RemoteJobMonitor

CONFIGURATIONDIRECTORY   = os.path.join(os.sep,'etc','submit')
DAEMONSCONFIGURATIONFILE = 'daemons.conf'

APPLICATIONLOGGER = logging.getLogger('') 

def openLogger():
   class EmptyFilter(logging.Filter):
      """
      This is a filter which rejects empty messages

      """

      def filter(self,record):
         if record.getMessage() == "":
            emptyRecord = True
         else:
            emptyRecord = False

         return(not emptyRecord)

   APPLICATIONLOGGER.setLevel(logging.DEBUG)

   logHandler = logging.StreamHandler()

   emptyFilter = EmptyFilter()
   logHandler.addFilter(emptyFilter)

   logFormatter = logging.Formatter('%(asctime)s %(message)s','[%a %b %d %H:%M:%S %Y]')
   logHandler.setFormatter(logFormatter)
   APPLICATIONLOGGER.addHandler(logHandler)


def monitorJobP(listenURI):
   """Report user priorities"""
   if len(sys.argv) == 1:
      hubUserIds = [os.getuid()]
   else:
      hubUserIds = []
      for arg in sys.argv[1:]:
         hubUserIds.append(int(arg))

   remoteJobMonitor = RemoteJobMonitor(listenURI)

   report = remoteJobMonitor.queryUsersPriority(hubUserIds)

   if len(report['usersPriority']) > 0:
      print("Report time %s" % (time.ctime(report['reportTime'])))

      print("%32s %8s  %12s\n" % ('Aggregator','UserId','Priority'))
      aggregators = report['usersPriority'].keys()
      aggregators.sort()
      for aggregator in aggregators:
         sortedPriorities = sorted([(priority,hubUserId) for hubUserId,priority in report['usersPriority'][aggregator].iteritems()],
                                                                                                                       reverse=True)
         for priority,hubUserId in sortedPriorities:
            print("%32s %8d  %12.3f" % (aggregator,hubUserId,priority))
   else:
      print("Current time %s" % (time.ctime()))
      print("No priorities currently being reported")


if __name__ == '__main__':
   openLogger()

   configFilePath = os.path.join(CONFIGURATIONDIRECTORY,DAEMONSCONFIGURATIONFILE)
   daemonsInfo    = DaemonsInfo(configFilePath)
   listenURI      = daemonsInfo.getDaemonListenURI('jobMonitor','tcp')

   monitorJobP(listenURI)
